from retico_core.core import abstract
from sds_class_iu import SimpleTextIU
import nltk


class TaggerModule(abstract.AbstractModule):

    @staticmethod
    def name():
        return "TaggerModule"

    @staticmethod
    def description():
        return "A Module that produces parts of speech"

    @staticmethod
    def input_ius():
        return [SimpleTextIU]

    @staticmethod
    def output_iu():
        return SimpleTextIU

    def __init__(self, **kwargs):
        """Initializes the OpenDialModule.

        Args:
            domain_dir (str): The path to the directory of the domain model (XML) for OpenDial
        """
        super().__init__(**kwargs)
        self.prefix = []

    def process_update(self, update_message):
        for iu,um in update_message:
            if um == abstract.UpdateType.ADD:
                update = self.process_iu(iu)
            elif um == abstract.UpdateType.REVOKE:
                update = self.revoke(iu)
        return update


    def process_iu(self, input_iu):
        print(input_iu)
        self.prefix.append(input_iu.get_word())
        pos = nltk.pos_tag(self.prefix)
        print(pos)
        new_iu = self.create_iu(input_iu)
        new_iu.payload = pos[-1][1]
        new_update = abstract.UpdateMessage.from_iu(new_iu, "add")
        return new_update

    def revoke(self, input_iu):
        print(input_iu)
        self.prefix.pop()

    def start(self):
        print('TaggerModule started!')


#!/usr/bin/env python3

"""
Setup script.

Use this script to install the core of the retico simulation framework. Usage:
    $ python3 setup.py install

Author: Thilo Michael (uhlomuhlo@gmail.com)
"""

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup


import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / "README.md").read_text(encoding="utf-8")

config = {
    "description": "A framework for real time incremental dialogue processing.",
    "long_description": long_description,
    "long_description_content_type": "text/markdown",
    "author": "Thilo Michael",
    "author_email": "uhlomuhlo@gmail.com",
    "author": "Ryan Pacheco",
    "author_email": "ryanpacheco413@u.boisestate.edu",
    "version": "0.1.01",
    "python_requires": ">=3.6, <4",
    "keywords": "retico, framework, incremental, dialogue, dialog",
    "install_requires": ["pyaudio>=0.2.12",
                         "nltk>=3.8.1",
                         "librosa>=0.10.1",
                         "torchvision>=0.17.0",
                         "transformers>=4.37.2",
                         "colorama>=0.4.6",
                         "retico-core-core>=0.1.0"],
    "py_modules": [
                   "sds_class_iu",
                   "TaggerModule"
                   ],
    "name": "retico-core-sds-class",
    "classifiers": [
        "Development Status :: 2 - Pre-Alpha",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
    ],
}

setup(**config)



from retico_core.core import abstract


class SimpleTextIU(abstract.IncrementalUnit):
    """
    """

    @staticmethod
    def type():
        return "SimpleTextIU"

    def __init__(self, creator=None, iuid=0, previous_iu=None, grounded_in=None, word=None,
                 **kwargs):
        super().__init__(creator=creator, iuid=iuid, previous_iu=previous_iu,
                         grounded_in=grounded_in, payload=word)
        self.word = word

    def get_word(self):
        return self.word
    
class SimpleTextUpdate(abstract.UpdateMessage):
    @staticmethod
    def type():
        return "SimpleUpdateMessage"
    
    def __init__(self, creator=None, iuid=0, previous_iu=None, grounded_in=None, word=None,
                 **kwargs):
        super().__init__()
        text_iu = SimpleTextIU(creator, iuid, previous_iu, grounded_in, word)
        self.add_iu(text_iu,"add")